@@ -59,6 +59,11 @@
 #include "enumerate.h"
 #include "enumdefs.h"
 
+#ifdef WIN32
+#define VERSION_NAME(W) W##2_4
+#define PYTHON_VERSION "2_4"
+#endif /* WIN32 */
+
 /* INNER_LOOP is executed in every iteration of the combinatorial enumerator
    macros DECK_ENUMERATE_n_CARDS_D() and DECK_ENUMERATE_PERMUTATIONS_D.  It
    evaluates each player's hand based on the enumerated community cards and
@@ -1078,9 +1083,9 @@ static PyMethodDef base_methods[] = {
 extern "C" {
 #endif
 DL_EXPORT(void)
-initpypokereval(void)
+VERSION_NAME(init_pokereval_)(void)
 {
-  Py_InitModule("pypokereval", base_methods);
+  Py_InitModule("_pokereval_" PYTHON_VERSION , base_methods);
 }
 #ifdef __cplusplus
 }
